<?php
/**
 * Check if Classic Editor plugin is active.
 *
 * @return bool
 */
function mtheme_is_classic_editor_plugin_active() {
    if ( ! function_exists( 'is_plugin_active' ) ) {
        include_once ABSPATH . 'wp-admin/includes/plugin.php';
    }

    if ( is_plugin_active( 'classic-editor/classic-editor.php' ) ) {
        return true;
    }

    return false;
}
function mtheme_is_gutenberg() {
	global $wp_version;
	if ( version_compare( $wp_version, '5.0', '>=' ) ) {
		return true;
	} else {
		return false;
	}
}
/**
 * Check pagebuilder on or off
 * @param  [type] $the_post_id [description]
 * @return [type]              [description]
 */
function mtheme_is_pagebuilder_on( $the_post_id ) {
	$status                = false;
	$current_switch_status = get_post_meta($the_post_id, 'mtheme_pb_isactive', true);

	if ( 1 == $current_switch_status ) {
		$status = true;
	}

	if ( isset( $_GET['builder_nonce'] ) ) {
		if ( wp_verify_nonce($_GET['builder_nonce'],'_wpnonce_mtheme_builder_setter') ) {
			if ( isset( $_GET['pagebuilder'] ) ) {
				if ( 'on' === $_GET['pagebuilder'] ) {
					delete_post_meta($the_post_id, 'mtheme_pb_isactive');
					update_post_meta($the_post_id, 'mtheme_pb_isactive', '1');	
					$status = true;		
				}
				if ( 'off' === $_GET['pagebuilder'] ) {
					delete_post_meta($the_post_id, 'mtheme_pb_isactive');
					update_post_meta($the_post_id, 'mtheme_pb_isactive', '2');
					$status = false;		
				}
			}
		}
	}
	
	return $status;
}
/**
 * Disable Gutenberg editor for Pagebuilder built pages
 * @param  [type] $can_edit [description]
 * @param  [type] $post     [description]
 * @return [type]           [description]
 */
function mtheme_disable_gutenberg_on_pagebuilder_builds($can_edit, $post) {
	
	if (empty($post->ID)) return $can_edit;
	
	$template_id = $post->ID;
	$current_switch_status = get_post_meta($template_id, 'mtheme_pb_isactive', true);

	if ( isset( $_GET['builder_nonce'] ) ) {
		if ( wp_verify_nonce($_GET['builder_nonce'],'_wpnonce_mtheme_builder_setter') ) {
			if ( isset( $_GET['pagebuilder'] ) ) {
				if ( 'on' === $_GET['pagebuilder'] ) {
					delete_post_meta($template_id, 'mtheme_pb_isactive');
					update_post_meta($template_id, 'mtheme_pb_isactive', '1');
					return false;		
				}
				if ( 'off' === $_GET['pagebuilder'] ) {
					delete_post_meta($template_id, 'mtheme_pb_isactive');
					update_post_meta($template_id, 'mtheme_pb_isactive', '2');
					$the_post_type = get_post_type();
					if ( mtheme_is_classic_editor_plugin_active() || 'mtheme_portfolio' === $the_post_type || 'mtheme_events' === $the_post_type ) {
						return false;
					} else {
						return true;
					}
				}
			}
		}
	}

	if ($current_switch_status == 1 ) {
		return false;
	}
	
	return $can_edit;
	
}
// Checker Gutenberg for WordPress >= 5.0
add_filter('use_block_editor_for_post', 'mtheme_disable_gutenberg_on_pagebuilder_builds', 10, 2);

add_action('wp_ajax_mtheme_gutenberg_check_page_mode','mtheme_gutenberg_check_page_mode');
/**
 * Check if page has been published or in auto-draft ( not published yet)
 * @return [type] [description]
 */
function mtheme_gutenberg_check_page_mode() {

	check_ajax_referer( 'builder', 'security' );
	$template_id = isset($_POST['template_id']) ? $_POST['template_id'] : '';
	$current_page_status = get_post_status($template_id);
	$current_switch_status = get_post_meta($template_id, 'mtheme_pb_isactive', true);

	if ($current_page_status == 'auto-draft') {
		echo 'unpublished';
	} else {
		echo $current_switch_status;
	}
	
	die;
};
add_action('wp_ajax_mtheme_save_gutenberg_switch_on','mtheme_save_gutenberg_switch_on');
/**
 * Save pagebuilder meta switch ON - used via ajax
 * @return [type] [description]
 */
function mtheme_save_gutenberg_switch_on() {

	check_ajax_referer( 'builder', 'security' );

	$template_id = isset($_POST['template_id']) ? $_POST['template_id'] : '';
	$current_page_status = get_post_status($template_id);

	if ($current_page_status !== 'auto-draft') {
		delete_post_meta($template_id, 'mtheme_pb_isactive');
		update_post_meta($template_id, 'mtheme_pb_isactive', '1');

		$current_switch_status = get_post_meta($template_id, 'mtheme_pb_isactive', true);

		echo 'post status is ' . $current_page_status . ' ';
		echo '|| ';
		echo 'page id ' . $template_id . ' builder switched on ';
		echo 'Current status for page is : ' . $current_switch_status;

	} else {
		echo $current_page_status;
	}

	die;
};
add_action('wp_ajax_mtheme_save_gutenberg_switch_off','mtheme_save_gutenberg_switch_off');
/**
 * Save pagebuilder meta switch OFF - used via ajax
 * @return [type] [description]
 */
function mtheme_save_gutenberg_switch_off() {

	check_ajax_referer( 'builder', 'security' );

	$template_id = isset($_POST['template_id']) ? $_POST['template_id'] : '';
	$current_page_status = get_post_status($template_id);

	if ($current_page_status !== 'auto-draft') {
		
		delete_post_meta($template_id, 'mtheme_pb_isactive');
		update_post_meta($template_id, 'mtheme_pb_isactive', '2');

		$current_switch_status = get_post_meta($template_id, 'mtheme_pb_isactive', true);

		echo 'post status is ' . $current_page_status . ' ';
		echo '|| ';
		echo 'page id ' . $template_id . ' builder switched off ';
		echo 'Current status for page is : ' . $current_switch_status;

	} else {
		echo $current_page_status;
	}

	die;
};

/**
 * Add builder switch to pagebuilder header
 */
if ( !function_exists( 'mtheme_gutenberg_builder_button' ) ) {
	function mtheme_gutenberg_builder_button( $post ) {

		$nonce = wp_create_nonce( '_wpnonce_mtheme_builder_setter' );
		$post_type = ! empty($post) ? $post->post_type : get_current_screen()->post_type;
		if ( 'page' !== $post_type && 'post' !== $post_type && 'mtheme_portfolio' !== $post_type && 'mtheme_events' !== $post_type )
			return;
		?>
		<div class="mtheme-edit-pb-wrap clearfix">
			<div class="mtheme-edit-pb">
				<i class="fa fa-cubes"></i> <?php _e('Using Page Builder.','mthemelocal'); ?> <span class="mtheme-gutenberg-pb-change"><?php _e('Switch','mthemelocal'); ?></span>
			</div>
			<div class="mtheme-edit-visual">
				<span class="mtheme-page-using-editor"><?php _e('Using Editor.','mthemelocal'); ?></span><span class="mtheme-gutenberg-pb-change"><?php _e('Change','mthemelocal'); ?></span>
			</div>
			<div class="mtheme-edit-null">
				<span class="mtheme-pb-choice mtheme-gutenberg-pb-yes"><a href="<?php echo get_edit_post_link( get_the_ID() ); ?>&pagebuilder=on&builder_nonce=<?php echo $nonce; ?>"><i class="fa fa-cubes"></i> <?php _e('Switch to Pagebuilder','mthemelocal'); ?></a></span>
				<span class="mtheme-pb-choice mtheme-gutenberg-pb-no"><a href="<?php echo get_edit_post_link( get_the_ID() ); ?>&pagebuilder=off&builder_nonce=<?php echo $nonce; ?>"><?php _e('Switch to Editor','mthemelocal'); ?></a></span>
			</div>
		</div>
		<?php
	}
}
add_action( 'mtheme_generate_pagebuilder_choice', 'mtheme_gutenberg_builder_button' );

/**
 * Gutenberg admin body classes
 * @param  [type] $classes [description]
 * @return [type]          [description]
 */
function gutenberg_admin_body_class( $classes ) {
	if ( mtheme_is_pagebuilder_on( get_the_ID() ) ) {
		$classes .= ' mtheme-pagebuilder-is-on';
	} else {
		$classes .= ' mtheme-pagebuilder-is-off';
	}
	if ( mtheme_is_gutenberg() ) {
		$classes .= ' mtheme-is-gutenberg';
	} else {
		$classes .= ' mtheme-is-not-gutenberg';
	}
	return $classes;
}
add_filter( 'admin_body_class', 'gutenberg_admin_body_class' );
